==> igniteui-react-core-18.1.2.tgz: package/esm5/lib/WebSummaryExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryExpressionDescription } from "./WebSummaryExpressionDescription";
/**
 * @hidden
 */
var WebSummaryExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSummaryExpressionDescriptionMetadata, _super);
    function WebSummaryExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSummaryExpressionDescriptionMetadata.b = function (a) {
        if (WebSummaryExpressionDescriptionMetadata.a == null) {
            WebSummaryExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSummaryExpressionDescriptionMetadata.c(WebSummaryExpressionDescriptionMetadata.a);
        }
        if (a.j(WebSummaryExpressionDescriptionMetadata.a)) {
            return;
        }
        a.y(WebSummaryExpressionDescriptionMetadata.a);
    };
    WebSummaryExpressionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SummaryExpression");
        a.item("__packageNameWC", "String:grids");
        a.item("__isPlainObject", "Boolean");
        a.item("FieldName", "String");
    };
    WebSummaryExpressionDescriptionMetadata.d = function (a) {
        WebSummaryExpressionDescriptionMetadata.b(a);
        a.aa("WebSummaryExpression", function () { return new WebSummaryExpressionDescription(); });
        a.z("WebSummaryExpression", WebSummaryExpressionDescriptionMetadata.a);
    };
    WebSummaryExpressionDescriptionMetadata.$t = markType(WebSummaryExpressionDescriptionMetadata, 'WebSummaryExpressionDescriptionMetadata');
    WebSummaryExpressionDescriptionMetadata.a = null;
    return WebSummaryExpressionDescriptionMetadata;
}(Base));
export { WebSummaryExpressionDescriptionMetadata };

==> igniteui-react-core-18.1.3.tgz: package/esm5/lib/WebSummaryExpressionDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { __extends } from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebSummaryExpressionDescription } from "./WebSummaryExpressionDescription";
/**
 * @hidden
 */
var WebSummaryExpressionDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    __extends(WebSummaryExpressionDescriptionMetadata, _super);
    function WebSummaryExpressionDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebSummaryExpressionDescriptionMetadata.b = function (a) {
        if (WebSummaryExpressionDescriptionMetadata.a == null) {
            WebSummaryExpressionDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebSummaryExpressionDescriptionMetadata.c(WebSummaryExpressionDescriptionMetadata.a);
        }
        if (a.k(WebSummaryExpressionDescriptionMetadata.a)) {
            return;
        }
        a.aa(WebSummaryExpressionDescriptionMetadata.a);
    };
    WebSummaryExpressionDescriptionMetadata.c = function (a) {
        a.item("__qualifiedNameTS", "String:SummaryExpression");
        a.item("__packageNameWC", "String:grids");
        a.item("__skipModuleRegisterWebComponents", "Boolean");
        a.item("__importOverrideWebComponents", "String:igniteui-webcomponents-grids/grids/combined");
        a.item("__importTypesWebComponents", "String:igniteui-webcomponents-grids/grids");
        a.item("__isPlainObject", "Boolean");
        a.item("FieldName", "String");
    };
    WebSummaryExpressionDescriptionMetadata.d = function (a) {
        WebSummaryExpressionDescriptionMetadata.b(a);
        a.ac("WebSummaryExpression", function () { return new WebSummaryExpressionDescription(); });
        a.ab("WebSummaryExpression", WebSummaryExpressionDescriptionMetadata.a);
    };
    WebSummaryExpressionDescriptionMetadata.$t = markType(WebSummaryExpressionDescriptionMetadata, 'WebSummaryExpressionDescriptionMetadata');
    WebSummaryExpressionDescriptionMetadata.a = null;
    return WebSummaryExpressionDescriptionMetadata;
}(Base));
export { WebSummaryExpressionDescriptionMetadata };
